# becca_viz
Visualization tools for becca

Making a visual representation of what is going on in a complex system is the most powerful way I know of to debug it. It also makes cool pictures.

The visualize() method within viz.py can be called to create an image of becca's internal activities at a given time step. A series of these can be stitched together into a video.
